@@ -14,53 +14,48 @@ Examples:
     [
       {
         "destination": "default",
-        "gateway": "gateway",
+        "gateway": "_gateway",
         "genmask": "0.0.0.0",
         "flags": "UG",
-        "metric": 100,
+        "metric": 202,
         "ref": 0,
         "use": 0,
         "iface": "ens33",
         "mss": 0,
         "window": 0,
-        "irtt": 0
-      },
-      {
-        "destination": "172.17.0.0",
-        "gateway": "0.0.0.0",
-        "genmask": "255.255.0.0",
-        "flags": "U",
-        "metric": 0,
-        "ref": 0,
-        "use": 0,
-        "iface": "docker",
-        "mss": 0,
-        "window": 0,
-        "irtt": 0
+        "irtt": 0,
+        "flags_pretty": [
+          "UP",
+          "GATEWAY"
+        ]
       },
       {
         "destination": "192.168.71.0",
         "gateway": "0.0.0.0",
         "genmask": "255.255.255.0",
         "flags": "U",
-        "metric": 100,
+        "metric": 202,
         "ref": 0,
         "use": 0,
         "iface": "ens33",
         "mss": 0,
         "window": 0,
-        "irtt": 0
+        "irtt": 0,
+        "flags_pretty": [
+          "UP"
+        ]
       }
     ]
 
+
     $ route -ee | jc --route -p -r
     [
       {
         "destination": "default",
-        "gateway": "gateway",
+        "gateway": "_gateway",
         "genmask": "0.0.0.0",
         "flags": "UG",
-        "metric": "100",
+        "metric": "202",
         "ref": "0",
         "use": "0",
         "iface": "ens33",
@@ -68,25 +63,12 @@ Examples:
         "window": "0",
         "irtt": "0"
       },
-      {
-        "destination": "172.17.0.0",
-        "gateway": "0.0.0.0",
-        "genmask": "255.255.0.0",
-        "flags": "U",
-        "metric": "0",
-        "ref": "0",
-        "use": "0",
-        "iface": "docker",
-        "mss": "0",
-        "window": "0",
-        "irtt": "0"
-      },
       {
         "destination": "192.168.71.0",
         "gateway": "0.0.0.0",
         "genmask": "255.255.255.0",
         "flags": "U",
-        "metric": "100",
+        "metric": "202",
         "ref": "0",
         "use": "0",
         "iface": "ens33",
@@ -95,13 +77,14 @@ Examples:
         "irtt": "0"
       }
     ]
+
 """
 import jc.utils
 import jc.parsers.universal
 
 
 class info():
-    version = '1.0'
+    version = '1.1'
     description = 'route command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -128,17 +111,20 @@ def process(proc_data):
 
         [
           {
-            "destination":  string,
-            "gateway":      string,
-            "genmask":      string,
-            "flags":        string,
-            "metric":       integer,
-            "ref":          integer,
-            "use":          integer,
-            "mss":          integer,
-            "window":       integer,
-            "irtt":         integer,
-            "iface":        string
+            "destination":     string,
+            "gateway":         string,
+            "genmask":         string,
+            "flags":           string,
+            "flags_pretty": [
+                               string,
+            ]
+            "metric":          integer,
+            "ref":             integer,
+            "use":             integer,
+            "mss":             integer,
+            "window":          integer,
+            "irtt":            integer,
+            "iface":           string
           }
         ]
     """
@@ -152,6 +138,29 @@ def process(proc_data):
                 except (ValueError):
                     entry[key] = None
 
+        # add flags_pretty
+        # Flag mapping from https://www.man7.org/linux/man-pages/man8/route.8.html
+        if 'flags' in entry:
+            flag_map = {
+                'U': 'UP',
+                'H': 'HOST',
+                'G': 'GATEWAY',
+                'R': 'REINSTATE',
+                'D': 'DYNAMIC',
+                'M': 'MODIFIED',
+                'A': 'ADDRCONF',
+                'C': 'CACHE',
+                '!': 'REJECT'
+            }
+
+            pretty_flags = []
+
+            for flag in entry['flags']:
+                if flag in flag_map:
+                    pretty_flags.append(flag_map[flag])
+
+            entry['flags_pretty'] = pretty_flags
+
     return proc_data
 
 
